Arch Packaging Files
--------------------

You can find the source files for [ansible-git][1] in the [Arch User Repository][2] and for the stable version [ansible][3] you can do so in \[community\].

  [1]: https://aur.archlinux.org/packages/ansible-git/
  [2]: https://wiki.archlinux.org/index.php/Arch_User_Repository
  [3]: https://www.archlinux.org/packages/community/any/ansible/
